package com.fs.company.mapper;

import java.util.List;
import com.fs.company.domain.CompanyProductOutstock;

/**
 * 出库Mapper接口
 * 
 * @author fs
 * @date 2025-07-01
 */
public interface CompanyProductOutstockMapper 
{
    /**
     * 查询出库
     * 
     * @param id 出库主键
     * @return 出库
     */
    public CompanyProductOutstock selectCompanyProductOutstockById(Long id);

    /**
     * 查询出库列表
     * 
     * @param companyProductOutstock 出库
     * @return 出库集合
     */
    public List<CompanyProductOutstock> selectCompanyProductOutstockList(CompanyProductOutstock companyProductOutstock);

    /**
     * 新增出库
     * 
     * @param companyProductOutstock 出库
     * @return 结果
     */
    public int insertCompanyProductOutstock(CompanyProductOutstock companyProductOutstock);

    /**
     * 修改出库
     * 
     * @param companyProductOutstock 出库
     * @return 结果
     */
    public int updateCompanyProductOutstock(CompanyProductOutstock companyProductOutstock);

    /**
     * 删除出库
     * 
     * @param id 出库主键
     * @return 结果
     */
    public int deleteCompanyProductOutstockById(Long id);

    /**
     * 批量删除出库
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCompanyProductOutstockByIds(Long[] ids);
}
